define("common/static/ui/q.ui.dialog/q.ui.dialog",["css!common/static/ui/q.ui.dialog/q.ui.dialog_css"],function(require, exports, module){

/* \u901a\u7528\u5f39\u51fa\u6846\u63d2\u4ef6 by luzhe */
/* \u652f\u6301dialog, alert, confirm\u4e09\u4e2a\u65b9\u6cd5\uff0c\u5176\u4e2d\u540e\u4e24\u4e2a\u4e3adialog\u7684\u7b80\u6613\u7248*/

/* 
 * options: {
 *   title        \u6807\u9898
 *   content      \u5185\u5bb9\uff0c\u53ef\u4ee5\u63d2\u5165html\u6807\u7b7e
 *   btns: [{     \u652f\u6301\u591a\u4e2a\u81ea\u5b9a\u4e49\u6309\u94ae
 *     btnText    \u6309\u94ae\u6587\u5b57
 *     btnClass   \u52a0\u5728dialog-btn\u4e4b\u540e, \u6700\u5e38\u7528\u7684\u4e3adialog-btn-blue
 *     closeFlag  \u70b9\u51fb\u662f\u5426\u5173\u95ed\u7a97\u53e3
 *     btnAction  \u6309\u94ae\u54cd\u5e94\u4e8b\u4ef6
 *   }]
 *   closeAction  \u7a97\u53e3\u5173\u95ed\u4e8b\u4ef6
 *   zIndex       \u7a97\u53e3\u7684z-index\u503c
 *   wrapperClass \u81ea\u5b9a\u4e49\u7684class\uff0c\u53ef\u4ee5\u4fee\u6539wrapper\u7684\u6837\u5f0f
 * }
 */
var dialog = function(options) {
    var opt = options || {},
        title = opt.title || '',
        content = opt.content || '',
        btns = opt.btns,
        closeAction = opt.close,
        zIndex = opt.zIndex || 204
    wpClass = opt.wrapperClass ? opt.wrapperClass : '';

    var $dialogWrapper = $('<div class="dialog-wrapper ' + wpClass +
            '"></div>')
        .css({
            zIndex: zIndex
        })
        .appendTo(document.body);
    var $overlay = $('<div class="dialog-overlay"></div>')
        .appendTo(document.body);

    $dialogWrapper.bind('close.dialog', function() {
        _unbindEvents($dialogWrapper);
        $dialogWrapper.remove();
        $overlay.remove();
    })
        .bind('resize.dialog', function() {
            _setPosition($dialogWrapper);
        });

    $('<a href="#" class="dialog-close"></a>')
        .appendTo($dialogWrapper);
    $('.dialog-close, .dialog-overlay')
        .click(function(e) {
            e.preventDefault();
            $dialogWrapper.trigger('close.dialog');
            if (closeAction && typeof closeAction === 'function') {
                closeAction();
            }
        });

    $('<div class="dialog-title">' + title + '</div>')
        .appendTo($dialogWrapper);
    if (!!content) {
        $('<div class="dialog-content">' + content + '</div>')
            .appendTo($dialogWrapper);
    }
    var btns_box = $('<div class="dialog-btns"></div>')
        .appendTo($dialogWrapper);

    for (var i = 0, len = btns.length; i < len; i++) {
        (function(btn) {
            var class_name = btn.btnClass ? btn.btnClass : '';
            var $btn = $(
                '<a href="#" class="dialog-btn ' +
                btn.btnClass + '">' + btn.btnText + '</a>');
            $btn.appendTo(btns_box)
                .click(function(e) {
                    e.preventDefault();
                    var closeFlag = btn.closeFlag === false ? false :
                        true;
                    if (!!closeFlag) {
                        $dialogWrapper.trigger('close.dialog');
                    }
                    if (!!btn.btnAction && typeof btn.btnAction ===
                        'function') {
                        btn.btnAction();
                    }
                });
        })(btns[i]);
    }

    $(window)
        .resize(function() {
            $dialogWrapper.trigger('resize.dialog');
        });
    _setPosition($dialogWrapper);
}

/*
 * options \u53ef\u4ee5\u4e3a\u5b57\u7b26\u4e32\uff0c\u8868\u793a\u5f39\u7a97\u5185\u5bb9
 *
 * options {
 *   okText   \u786e\u5b9a\u6309\u94ae\u7684\u6587\u5b57
 *   okAction \u786e\u5b9a\u6309\u94ae\u7684\u4e8b\u4ef6
 * }
 *
 * \u4e0edialog\u65b9\u6cd5\u76f8\u6bd4\u53ea\u6709\u4e00\u4e2a\u53c2\u6570\u4e0d\u540c
 * \u4e0d\u9700\u8981btns\uff0c\u53ea\u9700\u4f20\u5165okText\u548cokAction\u5373\u53ef
 */
var alert = function(options) {
    if (typeof options == 'string') {
        dialog({
            title: options,
            btns: [{
                btnText: '\u786e\u5b9a',
                btnClass: 'dialog-btn-blue'
            }]
        });
        return;
    }

    options.btns = [{
        btnText: options.okText || '\u786e\u5b9a',
        btnClass: 'dialog-btn-blue',
        btnAction: options.okAction
    }];

    dialog(options);
};

/*
 * options {
 *   okText       \u786e\u5b9a\u6309\u94ae\u7684\u6587\u5b57
 *   okAction     \u786e\u5b9a\u6309\u94ae\u7684\u4e8b\u4ef6
 *   cancelText   \u53d6\u6d88\u6309\u94ae\u7684\u6587\u5b57
 *   cancelAction \u53d6\u6d88\u6309\u94ae\u7684\u4e8b\u4ef6
 * }
 *
 * \u4e0edialog\u65b9\u6cd5\u76f8\u6bd4\u53ea\u6709\u4e00\u4e2a\u53c2\u6570\u4e0d\u540c
 * \u4e0d\u9700\u8981btns\uff0c\u9700\u4f20\u5165okText,okAction,cancelText,cancelAction
 */
var confirm = function(options) {
    options.btns = [{
        btnText: options.okText,
        btnClass: 'dialog-btn-blue',
        btnAction: options.okAction
    }, {
        btnText: options.cancelText,
        btnAction: options.cancelAction
    }];

    dialog(options);
};

function _unbindEvents($dialogWrapper) {
    $dialogWrapper
        .unbind('.dialog')
        .find('.btn,.dialog-close')
        .unbind('click.dialog');
}

function _setPosition($dialogWrapper) {
    var width = $dialogWrapper.outerWidth();
    var height = $dialogWrapper.outerHeight();
    var left = ($(window)
        .width() - width) / 2;
    var top = ($(window)
        .height() - height) / 2;
    $dialogWrapper.css({
        left: left,
        top: top
    });
}

return {
    dialog: dialog,
    alert: alert,
    confirm: confirm
};


});